@@ -21,7 +21,7 @@ void on_whois_activate (GtkWidget * editable, gpointer data);
 void on_configure_button_clicked (GtkButton * widget, gpointer data);
 
 /* General stuff */
-void gn_quit_app (GtkWidget * widget, gpointer data);
+gboolean gn_quit_app (GtkWidget * widget, gpointer data);
 
 void on_about_activate (GtkWidget *menu_item, gpointer data);
 
